<?php

namespace Test\Test\Policies;

use Litepie\User\Contracts\UserPolicy;
use Test\Test\Models\Eee;

class EeePolicy
{

    /**
     * Determine if the given user can view the eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function view(UserPolicy $user, Eee $eee)
    {
        if ($user->canDo('test.eee.view') && $user->isAdmin()) {
            return true;
        }

        return $eee->user_id == user_id() && $eee->user_type == user_type();
    }

    /**
     * Determine if the given user can create a eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('test.eee.create');
    }

    /**
     * Determine if the given user can update the given eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function update(UserPolicy $user, Eee $eee)
    {
        if ($user->canDo('test.eee.edit') && $user->isAdmin()) {
            return true;
        }

        return $eee->user_id == user_id() && $eee->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Eee $eee)
    {
        return $eee->user_id == user_id() && $eee->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Eee $eee)
    {
        if ($user->canDo('test.eee.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given eee.
     *
     * @param UserPolicy $user
     * @param Eee $eee
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Eee $eee)
    {
        if ($user->canDo('test.eee.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
